Module state

Module state 

Structs

State
TimedPrefix

Functions

new_state
peer_up_withdraws_handler
process_update
Process a single pre-parsed update through the state machine Convenience wrapper for single update processing
process_updates
Process pre-parsed updates through the state machine This is the core processing logic used by both collectors and curators
synthesize_withdraw_update

Type Aliases

AsyncState
RouterPeerUpdate