Structs
Functions
- new_
state - peer_
up_ withdraws_ handler - process_
update - Process a single pre-parsed update through the state machine Convenience wrapper for single update processing
- process_
updates - Process pre-parsed updates through the state machine This is the core processing logic used by both collectors and curators
- synthesize_
withdraw_ update