pub async fn process_updates<T: StateStore>(
state: Option<AsyncState<T>>,
tx: Sender<Update>,
updates: Vec<Update>,
) -> Result<()>Expand description
Process pre-parsed updates through the state machine This is the core processing logic used by both collectors and curators